import Vinyl from 'vinyl';
import { Omit } from 'utility-types';

type Source = string | Vinyl;
type Options = string | string[] | ValidatedOptions;
type ValidatedOptions = {
    potSources?: Source | Source[];
    poSources?: string | string[] | null;
    srcDir?: string;
    domainInPOPath?: boolean;
    domainFromPOTPath?: boolean;
    domain?: string;
    srcGlobOptions?: object;
    wrapLength?: number;
    defaultContextAsFallback?: boolean;
    appendNonIncludedFromPO?: boolean;
    includePORevisionDate?: boolean;
    includeGenerator?: boolean;
    returnPOT?: boolean;
    writeFiles?: boolean;
    destDir?: string;
    logResults?: boolean;
};
type StandardizedOptions = Omit<ValidatedOptions, 'potSources' | 'poSources'> & {
    potSources?: Source[];
    poSources?: string[] | null;
    _pot_input_files?: Vinyl[];
    _po_input_files?: string[][];
};
type PreparedOptions = Required<StandardizedOptions>;

type AsyncCallbackResult = [true, Vinyl[]] | [false, string];
type AsyncCallback = (result: AsyncCallbackResult) => unknown;
declare const _default$2: (cb: AsyncCallback, options: Options) => void;

declare const _default$1: (options: Options) => Vinyl[];

/**
 * Process user supplied options and merge with default options.
 *
 * @param {mixed} options
 * @param {boolean} writeFiles Default value for `options.writeFiles`.
 *
 * @throws OptionError on invalid, missing or incompatible options.
 *
 * @return {object}
 */
declare const _default: (options: Options, defaultWriteFiles?: boolean) => PreparedOptions;

declare const testOptions: {
    wrapLength: number;
    defaultContextAsFallback: boolean;
    appendNonIncludedFromPO: boolean;
    includePORevisionDate: boolean;
    includeGenerator: boolean;
};

export { type AsyncCallback, _default$2 as default, _default as prepareOptions, _default$1 as sync, testOptions };
